/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the Ext Dependency Manager API License Agreement [1].
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/dependency-manager-ext-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.ext.dependency.maven20;

import org.bluestemsoftware.specification.eoa.DeploymentDependencies;
import org.bluestemsoftware.specification.eoa.ScopedDependency;

/**
 * Models a <code>ScopedDependency</code> within context of Maven 2.0 dependency management
 * system. A scoped dependency MUST specify scope 'compile', type 'jar' and MUST be flagged as
 * optional.
 * <p>
 * Transitive dependencies MUST be processed. To qualify as a transitive dependency a
 * dependency MUST specify scope 'compile' or scope 'runtime', type 'jar' and MUST NOT be be
 * flagged as optional.
 * 
 * @see DeploymentDependencies#getScopedDependencies()
 */

public interface MavenScopedDependency extends ScopedDependency {

    public static final String TYPE = "jar";

    public static final String SCOPE = "compile";

}
