/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the Ext Dependency Manager API License Agreement [1].
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/dependency-manager-ext-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.ext.dependency.maven20;

import org.bluestemsoftware.specification.eoa.DeploymentDependencies;
import org.bluestemsoftware.specification.eoa.SharedDependency;

/**
 * Models a <code>SharedDependency</code> within context of Maven 2.0 dependency management
 * system. A shared dependency MUST specify scope 'provided' and type 'jar'.
 * <p>
 * Note that scope 'provided' in this case implies that dependency is either 'provided' at
 * runtime by system (optional is false) or is 'provided' at runtime by 'engine' (optional is
 * true).
 * 
 * @see DeploymentDependencies#getSharedDependencies()
 */
public interface MavenSharedDependency extends SharedDependency {

    public static final String TYPE = "jar";

    public static final String SCOPE = "provided";

    /**
     * Indicates if dependency is required. A maven shared dependecy is required if 'optional'
     * flag is set to false. Otheriwse it is not required. See ancestor for additional
     * comments.
     * 
     * @return true if required, false if not.
     */
    public boolean isRequired();

}
